==> xcoral-3.2.tar.gz: xcoral-3.2/buttons_bits.h <==
/* ########################################################################

			       button.bm

   File: button.bm
   Path: /home/fournigault/c/X11/xcoral-2.31/data.h
   Description: 
   Created: Fri Jan 27 10:50:56 MET 1995
   Author: Lionel Fournigault
   Modified: Fri Jan 27 10:50:57 MET 1995
   Last maintained by: Lionel Fournigault

   RCS $Revision$ $State$
   

   ########################################################################

   Note: 

   ########################################################################

   Copyright (c) : Lionel Fournigault

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   ######################################################################## */

/*
	Les bitmaps pour les deplacements dans le buffer.
*/
#define head_width 24
#define head_height 24
extern unsigned char head_bits[];

#define q_width 24
#define q_height 24
extern unsigned char q_bits[];

#define np_width 24
#define np_height 24
extern unsigned char np_bits[];

#define down_width 24
#define down_height 24
extern unsigned char down_bits[];

#define pp_width 24
#define pp_height 24
extern unsigned char pp_bits[];

#define up_width 24
#define up_height 24
extern unsigned char up_bits[];

/*
	Les bitmaps pour le toolbar
*/

#define xlogo32_width 32
#define xlogo32_height 32
extern unsigned char xlogo32_bits[];

#define slogo_width 34
#define slogo_height 8
extern unsigned char slogo_bits[];

#define dired_width 32
#define dired_height 32
extern unsigned char dired_bits[];

#define new_window_width 32
#define new_window_height 32
extern unsigned char new_window_bits[];

#define save_width 32
#define save_height 32
extern unsigned char save_bits[];

#define man_width 32
#define man_height 32
extern unsigned char man_bits[];

#define cut_width 32
#define cut_height 32
extern unsigned char cut_bits[];

#define paste_width 32
#define paste_height 32
extern unsigned char paste_bits[];

#define c_width 32
#define c_height 32
extern unsigned char c_bits[];

#define cplus_width 32
#define cplus_height 32
extern unsigned char cplus_bits[];

#define java_width 32
#define java_height 32
extern unsigned char java_bits[];

#define dlt_width 32
#define dlt_height 32
extern unsigned char dlt_bits[];

#define latex_width 32
#define latex_height 32
extern unsigned char latex_bits[];

#define color_width 32
#define color_height 32
extern unsigned char color_bits[];

#define top_width 32
#define top_height 32
extern unsigned char top_bits[];

#define latex_util_width 32
#define latex_util_height 32
extern unsigned char latex_util_bits[];

#define html_width 32
#define html_height 32
extern unsigned char html_bits[];

#define rcs_width 32
#define rcs_height 32
extern unsigned char rcs_bits[];

#define cmds_width 32
#define cmds_height 32
extern unsigned char cmds_bits[];

#define cc_util_width 32
#define cc_util_height 32
extern unsigned char cc_util_bits[];

#define undo_width 32
#define undo_height 32
extern unsigned char undo_bits[];

/*
	Le logo 64x64 de Xcoral
*/
#define icon_width 64
#define icon_height 64
extern unsigned char icon_bits[];

==> xcoral_3.40.orig.tar.gz: xcoral-3.40/buttons_bits.h <==
#define logo_width 32
#define logo_height 32
extern unsigned char logo_bits[];

#define bwlogo_width 32
#define bwlogo_height 32
extern unsigned char bwlogo_bits[];
  
#define head_width 24
#define head_height 24
extern unsigned char head_bits[];

#define q_width 24
#define q_height 24
extern unsigned char q_bits[];

#define np_width 24
#define np_height 24
extern unsigned char np_bits[];

#define down_width 24
#define down_height 24
extern unsigned char down_bits[];

#define pp_width 24
#define pp_height 24
extern unsigned char pp_bits[];

#define up_width 24
#define up_height 24
extern unsigned char up_bits[];

extern char * bg_bpanel[];

#define xlogo32_width 32
#define xlogo32_height 32
extern unsigned char xlogo32_bits[];

#define slogo_width 40
#define slogo_height 8
extern unsigned char slogo_bits[];

#define dired_width 32
#define dired_height 32
extern unsigned char dired_bits[];

#define new_window_width 32
#define new_window_height 32
extern unsigned char new_window_bits[];

#define save_width 32
#define save_height 32
extern unsigned char save_bits[];

#define man_width 32
#define man_height 32
extern unsigned char man_bits[];

#define cut_width 32
#define cut_height 32
extern unsigned char cut_bits[];

#define paste_width 32
#define paste_height 32
extern unsigned char paste_bits[];

#define c_width 32
#define c_height 32
extern unsigned char c_bits[];

#define cplus_width 32
#define cplus_height 32
extern unsigned char cplus_bits[];

#define java_width 32
#define java_height 32
extern unsigned char java_bits[];

#define dlt_width 32
#define dlt_height 32
extern unsigned char dlt_bits[];

#define latex_width 32
#define latex_height 32
extern unsigned char latex_bits[];

#define latex_width 32
#define latex_height 32
extern unsigned char browser_bits[];

#define color_width 32
#define color_height 32
extern unsigned char color_bits[];

#define top_width 32
#define top_height 32
extern unsigned char top_bits[];

#define latex_util_width 32
#define latex_util_height 32
extern unsigned char latex_util_bits[];

#define html_width 32
#define html_height 32
extern unsigned char html_bits[];

#define rcs_width 32
#define rcs_height 32
extern unsigned char rcs_bits[];

#define cmds_width 32
#define cmds_height 32
extern unsigned char cmds_bits[];

#define cc_util_width 32
#define cc_util_height 32
extern unsigned char cc_util_bits[];

#define undo_width 32
#define undo_height 32
extern unsigned char undo_bits[];

#define icon_width 32
#define icon_height 32
extern unsigned char icon_bits[];

extern unsigned char *xpm_logo[];

extern unsigned char *xpm_dired_bits[];
extern unsigned char *xpm_new_window_bits[];
extern unsigned char *xpm_save_bits[];
extern unsigned char *xpm_cut_bits[];
extern unsigned char *xpm_paste_bits[];
extern unsigned char *xpm_undo_bits[];
extern unsigned char *xpm_dlt_bits[];
extern unsigned char *xpm_c_bits[];
extern unsigned char *xpm_cplus_bits[];
extern unsigned char *xpm_java_bits[];
extern unsigned char *xpm_latex_bits[];
extern unsigned char *xpm_browser_bits[];
extern unsigned char *xpm_color_bits[];
extern unsigned char *xpm_top_bits[];
extern unsigned char *xpm_man_bits[];
extern unsigned char *xpm_cc_util_bits[];
extern unsigned char *xpm_latex_util_bits[];
extern unsigned char *xpm_html_bits[];
extern unsigned char *xpm_rcs_bits[];
extern unsigned char *xpm_cmds_bits[];

extern unsigned char *xpm_head_bits[];
extern unsigned char *xpm_q_bits[];
extern unsigned char *xpm_np_bits[];
extern unsigned char *xpm_down_bits[];
extern unsigned char *xpm_pp_bits[];
extern unsigned char *xpm_up_bits[];
